/* Copyright (C) 2003 Covansys India
 
   This file is part of OpenSTA
 
   OpenSTA is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free
   Software Foundation; either version 2, or (at your option) any later
   version.
 
   OpenSTA is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.
 
   You should have received a copy of the GNU General Public License along
   with OpenSTA; see the file COPYING.  If not, write to the Free Software
   Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
   For more information about the GNU Public license see:
   http://www.gnu.org/copyleft/gpl.html
 
   OpenSTA is at:
   http://www.opensta.org/
   http://opensta.sourceforge.net/
*/
// BViewView.cpp : implementation of the CBViewView class
//

#include "stdafx.h"
#include "BView.h"
#include "BViewDoc.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CBViewView
IMPLEMENT_DYNCREATE(CBViewView, CHtmlView)
BEGIN_MESSAGE_MAP(CBViewView, CHtmlView)
	//{{AFX_MSG_MAP(CBViewView)
	ON_COMMAND(ID_NAVIGATE_BACK, OnNavigateBack)
	ON_COMMAND(ID_NAVIGATE_FORWARD, OnNavigateForward)
	ON_COMMAND(ID_FILE_OPEN, OnFileOpen)
	ON_UPDATE_COMMAND_UI(ID_NAVIGATE_BACK, OnUpdateNavigateBack)
	ON_UPDATE_COMMAND_UI(ID_NAVIGATE_FORWARD, OnUpdateNavigateForward)
	ON_COMMAND(ID_NAVIGATE_FIRST, OnNavigateFirst)
	ON_COMMAND(ID_NAVIGATE_LAST, OnNavigateLast)
	ON_UPDATE_COMMAND_UI(ID_NAVIGATE_FIRST, OnUpdateNavigateFirst)
	ON_UPDATE_COMMAND_UI(ID_NAVIGATE_LAST, OnUpdateNavigateLast)
	ON_COMMAND(ID_OPTION_SETSILENT, OnOptionSetsilent)
	ON_UPDATE_COMMAND_UI(ID_OPTION_SETSILENT, OnUpdateOptionSetsilent)
	ON_COMMAND(ID_BVIEW_COMMAND, OnBviewCommand)
	//}}AFX_MSG_MAP
	// Standard printing commands
	ON_COMMAND(ID_FILE_PRINT, CHtmlView::OnFilePrint)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CBViewView construction/destruction
CBViewView::CBViewView()
{

}

CBViewView::~CBViewView()
{
	sFileName.RemoveAll();
	sUrl.RemoveAll();
}

BOOL CBViewView::PreCreateWindow(CREATESTRUCT& cs)
{
	return CHtmlView::PreCreateWindow(cs);
}

/////////////////////////////////////////////////////////////////////////////
// CBViewView drawing
void CBViewView::OnDraw(CDC* pDC)
{
	CBViewDoc* pDoc = GetDocument();
	ASSERT_VALID(pDoc);
}

void CBViewView::OnInitialUpdate()
{
	CHtmlView::OnInitialUpdate();
	
	LoadFromResource(IDR_INTI);	//Loads the Initializing Page
	nPresent = -1;			//The array is Empty
	bsetsilent=false;
	SetSilent(false);		//Enables the popups in the Page
	SetOffline(false);		//Sets Online
}

/////////////////////////////////////////////////////////////////////////////
// CBViewView diagnostics
#ifdef _DEBUG
void CBViewView::AssertValid() const
{
	CHtmlView::AssertValid();
}

void CBViewView::Dump(CDumpContext& dc) const
{
	CHtmlView::Dump(dc);
}

CBViewDoc* CBViewView::GetDocument() // non-debug version is inline
{
	ASSERT(m_pDocument->IsKindOf(RUNTIME_CLASS(CBViewDoc)));
	return (CBViewDoc*)m_pDocument;
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CBViewView message handlers
void CBViewView::OnNavigateBack() 
{
	Navigate(sFileName[--nPresent]);
	((CMainFrame *)(::AfxGetApp()->m_pMainWnd))->SetAddressText(sUrl[nPresent]);
}

void CBViewView::OnNavigateForward() 
{
	Navigate(sFileName[++nPresent]);
	((CMainFrame *)(::AfxGetApp()->m_pMainWnd))->SetAddressText(sUrl[nPresent]);
}

void CBViewView::OnFileOpen() 
{
	CFileDialog m_ldFile(true, NULL, "*.inf",
		OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT,
		"Information Files (*.inf)|*.inf||",
		NULL);
	if (m_ldFile.DoModal() == IDOK)
	{
		m_infFileName = m_ldFile.GetPathName(); 
		infLoad();
	}
}

//The Function to load the *.inf file contents into an Array
void CBViewView::infLoad() 
{
	try
	{
		char buffer[1025];
		sUrl.RemoveAll();
		sFileName.RemoveAll();
		FILE* fp = fopen(m_infFileName, "r+");
		sUrl.RemoveAll();
	
		while(!feof(fp))
		{
			fgets(buffer, 1024, fp);
			buffer[strlen(buffer)-1] = '\0';
			sFileName.Add(buffer);
			if (!feof(fp))
			{
				fgets(buffer, 1024, fp);
				buffer[strlen(buffer)-1] = '\0';
				sUrl.Add(buffer);
			}
			else sFileName.SetSize(sUrl.GetSize()) ;		
		}
		nPresent = 0;
		fclose(fp);
	}
	catch(...)
	{
		sUrl.RemoveAll();
		sFileName.RemoveAll();
		nPresent = -1;
		::MessageBox(NULL,"Failed to Open the file","Error Message",MB_OK|MB_ICONERROR);
		return;
	}

	Navigate(sFileName[nPresent]);
	((CMainFrame *)(::AfxGetApp()->m_pMainWnd))->SetAddressText(sUrl[nPresent]);
}

void CBViewView::OnUpdateNavigateBack(CCmdUI* pCmdUI) 
{
	int max = sFileName.GetSize();
	pCmdUI->Enable((nPresent != 0) && (max != 0));
}

void CBViewView::OnUpdateNavigateForward(CCmdUI* pCmdUI) 
{
	int max = sFileName.GetSize();
	pCmdUI->Enable((nPresent < (max-1)) && (max > 1));
}

void CBViewView::OnNavigateFirst() 
{
	nPresent=0;
	Navigate(sFileName[nPresent]);
	((CMainFrame *)(::AfxGetApp()->m_pMainWnd))->SetAddressText(sUrl[nPresent]);
}

void CBViewView::OnNavigateLast() 
{
	nPresent=sFileName.GetSize()-1;
	Navigate(sFileName[nPresent]);
	((CMainFrame *)(::AfxGetApp()->m_pMainWnd))->SetAddressText(sUrl[nPresent]);
}

void CBViewView::OnUpdateNavigateFirst(CCmdUI* pCmdUI) 
{
	int max = sFileName.GetSize();
	pCmdUI->Enable((nPresent != 0) && (max != 0));
}

void CBViewView::OnUpdateNavigateLast(CCmdUI* pCmdUI) 
{
	if(nPresent == (sFileName.GetSize()-1))
	{
		int max = sFileName.GetSize();
		pCmdUI->Enable((nPresent < max-1) && (max > 1));
	}
}

void CBViewView::OnOptionSetsilent() 
{
	bsetsilent = !bsetsilent;
}

void CBViewView::OnUpdateOptionSetsilent(CCmdUI* pCmdUI) 
{	
	pCmdUI->SetCheck(bsetsilent?1:0);
	SetSilent(bsetsilent);
}

void CBViewView::OnBeforeNavigate2(LPCTSTR lpszURL, DWORD nFlags, LPCTSTR lpszTargetFrameName, CByteArray& baPostedData, LPCTSTR lpszHeaders, BOOL* pbCancel) 
{
	((CMainFrame *)(::AfxGetApp()->m_pMainWnd))->m_avicontrol.Play(0,-1,-1);
	CHtmlView::OnBeforeNavigate2(lpszURL, nFlags, lpszTargetFrameName, baPostedData, lpszHeaders, pbCancel);
}

void CBViewView::OnDocumentComplete(LPCTSTR lpszURL) 
{
	((CMainFrame *)(::AfxGetApp()->m_pMainWnd))->m_avicontrol.Stop();
	CHtmlView::OnDocumentComplete(lpszURL);
}

void CBViewView::OnBviewCommand() 
{
	LoadFromResource(IDR_HELP);
}